/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: gbmsgbox_l.h 947 2006-02-21 17:04:54Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef GB_MSGBOX_L_H
#define GB_MSGBOX_L_H

#include <gtk/gtk.h>

#include <gwenhywfar/types.h>
#include <aqbanking/banking.h>



GtkWidget *GB_MsgBox_new(AB_BANKING *ab,
                         GWEN_TYPE_UINT32 flags,
                         const char *title,
                         const char *text,
                         const char *b1,
                         const char *b2,
                         const char *b3,
                         GtkWidget *parent);



#endif /* GB_MSGBOX_L_H */



